Building neighbor-lists
=======================

The :class:`ase.calculators.emt.EMT` potential and the GPAW_ DFT calculator
both make use of ASE's built-in neighbor-list class:

.. autoclass:: ase.calculators.neighborlist.NeighborList
   :members:


.. _GPAW: http://wiki.fysik.dtu.dk/gpaw
